@@ -103,8 +103,9 @@ static void rl_handler(char *input)
 	}
 
 	if (len > 0) {
-
-		add_history(input);
+		HIST_ENTRY *previous = history_get(where_history());
+		if(!previous || strcmp(previous->line, input))
+			add_history(input);
 
 		err = __connmanctl_commands(connection, trim_args, len);
 
@@ -272,7 +273,7 @@ int __connmanctl_input_init(int argc, char *argv[])
 		__connmanctl_monitor_completions(NULL);
 
 		rl_callback_handler_remove();
-		rl_message("");
+		rl_message("%s", "");
 	}
 
 	dbus_connection_unref(connection);
